{% raw %}
{% load mote_tags i18n %}
{% mask element.json.data.Navigation as "section_nav" %}
<div class="navigation">
  <h4 class="heading heading--large">
    <a href="/" class="navigation__anchor">{% trans "Home" %}</a>
  </h4>
  <ul class="nav-list nav-list--{{section_nav.modifiers}}">
    {% for item in section_nav.navMenu %}
      <li class="nav-list__item nav-list__item--column">
        <a href="#" class="nav-list__anchor nav-list__anchor--column">{{item.text}}</a>
        <span class="nav-list__anchor-desc nav-list__anchor-desc--column">{{item.desc}}</span>
      </li>
    {% endfor %}
  </ul>
</div>
{% endraw %}
