.call-to-action__item-text--backto-top {
  border-top: 1px solid #000;
  padding: 10px 0;
  color: #000;
  display: inline-block;
  @media screen and (min-width: 320px) {
    text-decoration: none;
    padding: 20px 0 0;
    position: relative;
    width: auto;
  }
  &:after {
    content: "";
    background: url('../images/icons/chevron-up.svg') no-repeat 0 0 / auto 100%;
    height: 21px;
    width: 21px;
    position: absolute;
    right: 5px;
  }
  &:hover {
    text-decoration: none;
  }
}

.call-to-action--backto-top-bg {
  background: #F0F3F5;
  padding: 10px 0;
}
.call-to-action__item-text--backto-top-up_arrow {
  &:after {
    content: url("/static/images/icons/up-arrow.svg");
    right: 20%;
    top: 30%;
    position: absolute;
  }
}
