.heading__square {
  @include divider-bottom-1;
  background-color: $springster-purple;
  *:first-child {
    @include underline(skewed, 10px);
  }
}
.heading__component {
  @include underline(zig-zag, 10px);
  margin: 0 8px 28px;
  padding-top: 30px;
}
