.profiles {
  text-align: center;
  .heading__component {
    margin-bottom: 10px;
  }
  fieldset {
    text-align: center;
  }
  label {
    display: inline-block;
  }
  &__form--block {
    background: $pale-grey;
    margin: 30px auto;
    text-align: center;
  }
}
.profiles-join-banner {
  background-color: $springster-purple;
  padding: 10px 0;
  &__content {
    padding-bottom: 0;
  }
  &__icon  {
    padding-bottom: 0;
    background-image: url('/static/img/icons/mint-hand.svg'), url('/static/img/icons/wave.png');
    background-repeat: no-repeat;
    background-position: center 50%;
    background-size: 95px;
    width: 95px;
    height: 119px;
    margin: 0 auto;
  }
}
