
@font-face {
  font-family: 'BatonRegular';
  src: url('/static/fonts/Baton-Regular-Web.woff2') format('woff2'),
       url('/static/fonts/Baton-Regular-Web.woff') format('woff'),
       url('/static/fonts/Baton-Regular-Web.eot') format('truetype');
}
@font-face {
  font-family: 'BatonMedium';
  src: url('/static/fonts/Baton-Medium-Web.woff2') format('woff2'),
       url('/static/fonts/Baton-Medium-Web.woff') format('woff'),
       url('/static/fonts/Baton-Medium-Web.eot') format('truetype');
}
@font-face {
  font-family: 'BatonTurboRegular';
  src: url('/static/fonts/BatonTurboWeb-Regular.woff2') format('woff2'),
       url('/static/fonts/BatonTurboWeb-Regular.woff') format('woff'),
       url('/static/fonts/BatonTurboWeb-Regular.eot') format('truetype');
}
