/**
Take Note:
Separate smart styles to states folder
*/
.grid-teaser {
  overflow: auto;
}
.grid-teaser-list  {
  display: block;
  overflow: auto;
}
.grid-teaser-list__item {
  list-style-type: none;
  padding: 10px 0;
  float: left;
}

.grid-teaser__thumbnail {}
.grid-teaser__thumbnail-link {
  display: block;
}


.grid-teaser__title,
.gird-teaser__subtitle  {
  text-align: center;
}
.grid-teaser__title-link {
  color: gray;
}
