fieldset {
  border: none;
  font-family: $baton-regular;
  margin: 0;
  padding: 0 5%;;
  display: block;
  position: relative;
  &:last-of-type {
    padding-bottom: 0;
  }
}
textarea {
  font-family: $baton-regular;
  border: none;
  padding: 8px 8px 0;
  margin: 0 8px;
  display: block;
}

label, .checkbox__legend {
  font-size: $font-medium;
  padding: 10px 0 0;
  color: $gunmetal;
  text-transform: capitalize;
  display: initial;
  text-align: left;
}
.checkbox__label {
  display: block;
  text-transform: capitalize;;
}

.required-asterisk {
  color: #909497;
  font-size: 13px;
}
.required-info {
  color: #909497;
  display: block;
  font-size: 14px;
  font-weight: bold;
  margin: -5px 0 0;
}
.hint-text {
  color: #909497;
  display: block;
  font-size: 12px;
  font-weight: bold;
  padding-bottom: 5px;
  text-transform: capitalize;
}
.search-icon {
  font-size:12px;
  color: #909497;
}

.helptext {
  font-family: $baton-turbo;
  color: $slate-grey;
  font-size: $font-x-small;
}

.error-list,
.errorlist {
  margin: 0;
  padding: 0;
  li {
    display: block;
    color: $bright-orange;
    text-align: center;
  }
}
.errors, .error-list__item {
  color: $bright-orange;
  padding: 10px 15px 0;
  text-align: center;
}
label.error {
  .required-asterisk,
  .required-info {
    color: $bright-orange;
  }
input[type="submit"] {
  border: none;
  background: #fff;
}
  input[type="text"],
  input[type="number"],
  input[type="password"],
  input[type="email"],
  input[type="tel"],
  input[type="search"] {
    border: 1px solid red;
  }
}

input[type="text"],
input[type="number"],
input[type="password"],
input[type="email"],
input[type="tel"],
input[type="search"],
input[type="week"],
input[type="date"],
input[type="month"],
input[type="datetime"],
input[type="datetime-local"],
input[type="url"],
textarea, select {
  border: 2px solid $springster-purple;
  box-sizing: border-box;
  display: block;
  font-size: 16px;
  margin: 10px auto;
  padding: 10px 0 10px 5px;
  width: 98%;
  border-radius: 0;
  -webkit-appearance: none;
  -webkit-border-radius: 0px;
  &:focus {
    outline: 0;
  }
}

input[type="checkbox"],
input[type="radio"]  {
  display: inline-block;
  margin-left: 10px;
}
.choice,
.choice-group {
  margin: 0 0 10px;
  input[type="checkbox"],
  input[type="radio"] {
    position: initial;
    visibility: initial;
  }
}
.select-group {
  display: inline-block;
  padding: 15px 0;
}
.sub_label {
  display: block;
}

.input-group {
  &.input-error{
    input, textarea {
      border-color: $bright-orange;
    }
  }

  .error-message {
    color: $bright-orange;
  }
}
