$font-xx-large    :     32px;
$font-x-large     :     24px;
$font-large       :     22px;
$font-medium      :     20px;
$font-small       :     18px;
$font-x-small     :     16px;
$font-xx-small    :     14px;
$font-xxx-small   :     12px;

$baton-regular    :     'BatonRegular', Helvetica, Arial, sans-serif;
$baton-medium     :     'BatonMedium', Helvetica, Arial, sans-serif;
$baton-turbo      :     'BatonTurboRegular', Helvetica, Arial, sans-serif;

$screen-xx-small      :     240px;
$screen-small         :     320px;
$screen-medium        :     502px;
$screen-large         :     897px;

$heading-xx-large: (
  null: 17px,
  $screen-xx-small: 24px,
  $screen-small: 32px,
);

$heading-x-large: (
  null: 16px,
  $screen-xx-small: 21px,
  $screen-small: 24px,
);

$heading-large: (
  null: $font-xx-small,
  $screen-xx-small: $font-x-small,
  $screen-small: $font-medium,
);

// Grid Columns
$grid-one: 8.33%;
$grid-two: 16.667%;
$grid-three: 25%;
$grid-four: 33.333%;
$grid-five: 41.667%;
$grid-six: 50%;
$grid-seven: 58.333%;
$grid-eight: 66.667%;
$grid-nine: 75%;
$grid-ten: 83.333%;
$grid-eleven: 91.667%;
$grid-twelve: 100%;
$grid-gutter: 8px !global;

// Teaser ellipsis
$elip-line-height: 1.3;
$elip-lines-to-show: 2;

