//NAVIGATION
#profile .menu-list__anchor--section-nav,
#search .menu-list__anchor--section-nav {
  padding: 0;
}
.header__menu {
  text-align: left;
}
#profile {
  @media screen and (min-width: 360px) {
    float: right;
  }
}
.header__search .header__search-bar:after {
  @media screen and (min-width: 360px) {
    right: inherit;
    left: 3px;
  }
}
.section-nav .section-nav-list__item {
  padding: 5px 10px 2px 10px;
}

//TEASERS
.teaser-stacklist__item--content {
  margin: 0 10px 0;
}
.teaser-stacklist-tags__item {
  margin-left: 8px;
  margin-right: 0;
}

.base-teaser__thumbnail-link img {
  display: inline;
  padding: 0 20px 0 0;
  @media screen and (min-width: 360px) {
    display: block;
    padding: 0;
  }
}

//ARTICLE HEADING
.heading__article  {
  text-align: right;
}

//TAG CLOUD
.tag-cloud__block {
  text-align: right;
}

//FORM
.choice label {
  text-align: left;
  padding: 0;
  @media screen and (min-width: 500px) {
    padding: 16px 54px 16px 10px;
  }
}
.choice input[type=checkbox]+label,
.choice input[type=radio]+label,
.choice input[type=checkbox]:checked+label,
.choice input[type=radio]:checked+label {
  @media screen and (min-width: 500px) {
    background-position-x: 95%;
  }
}

.profiles fieldset {
  text-align: right;
}

//BUTTONS
.call-to-action__item--with-icon,
.call-to-action__nav-item--with-icon {
  @media screen and (min-width: 360px) {
    right: inherit;
    left: 5px;
  }
}
.call-to-action__item--search-icon,
.call-to-action__nav-item--search-icon {
  right: inherit !important;
  left: 15px;
}

//COMMENTS
.comments__publish-date {
  padding: 5px 15px 0 15px;
}
.comment-counter__numeral {
  margin-right: 5px;
}
.teaser-stacklist__item--content .comment-counter {
  @media screen and (min-width: 360px) {
    right: inherit !important;
    left: 10px;
  }
}
//YOURWORDS
.yourwords {
  text-align: right;
}

//PAGINATION
.pagination {
  text-align: right;
}

//FOOTER
.copyright__footer-copy {
  text-align: right;
}
