@media only screen and (min-width: 320px){
  .header {
    box-sizing: border-box;
    padding: 10px 10px 5px;
  }
  .header-fixed {
    position: fixed;
    top: 0;
    z-index: 9999;
    width: 100%;
    box-sizing: border-box;
    transform: translate3d(0px, 0px, 0px);
    transition: transform 300ms ease 0ms; 
    animation: qs-timer 300ms;
  }
}

