{% load core_tags %}
<div class="article-teaser">
{% load_descendant_articles_for_section section featured_in_homepage=True as featured_articles %}
{% if featured_articles %}
  <ul class="teaser-stacklist">
    {% for article in featured_articles %}
    <li class="teaser-stacklist__item">
      {% include "patterns/basics/article-teasers/sp_variations/teaser-thumbnail.html" with layouttype="base" %}
      <div class="teaser-stacklist__item--content">
        {% include "patterns/basics/article-teasers/sp_variations/teaser-title.html" with layouttype="base" %}
      </div>
    </li>
    {% endfor %}
  </ul>
{% endif %}
</div>
