//Article Social Media Styles
.social-media-list {
    display: block;
    text-align: center;
    margin: 0;
    padding: 0 0 15px;
  &__item {
    display: inline-block;
    vertical-align: middle;
    padding: 0 2px;
  }
}
.social-media__label {
  padding: 0;
  margin: -5px 0 0;
}
