html, body  {
  font-family: Arial, Helvetica, sans-serif;
  margin: 0 auto;
  position: relative;
  line-height: 1.3;
  font-size: $font-x-small;
}
body, .content  {
  background-color: $white;
  overflow: auto;
}

a {
  text-decoration: none;
  outline: none;
  &:hover {
    text-decoration: underline;
  }
  &:focus {
    outline: 0;
  }
  img {
    outline: none;
  }
}
img {
  border: 0;
}
h1,h2,h3,h4,h5,h6 {
  font-weight: bold;
}
h1,h2,h3,h4,h5,h6,p {
  margin: 0;
}
