.section-teaser-listing-header {
  @include grid(100%);
  margin: 8px 8px 0;
  padding: 65px 0;
  max-height: 128px;
  .heading__section {
    @include column($grid-six);
    position: absolute;
    bottom: 0;
    padding-left: 0;
    padding-right: 0;
    padding-bottom: 0;
    left: 0;
    h1 {
      font-size: 40px;
      margin: 12px 0 8px 8px;
    }
  }
  .section-banner {
    text-align: right;
    position: absolute;
    right: 0;
    top: 0;
  }
}
