.tag-cloud {
  display: inline-block;
  width: 100%;
  margin-top: 45px;
  position: relative;
  &__container {
    background-color: $sunny-yellow;
    padding: 60px 1em 0 1em;
    margin-top: 40px;
  }
  &__block {
    width: 100%;
    text-align: center;
    margin: 20px 0 0;
    padding: 0 0 20px;
    list-style-type: none;
  }
  &__icon {
    background: url(/static/img/tag-cloud-love-hands.svg), url(/static/img/tag-cloud-love-hands.png);
    background-repeat: no-repeat;
    background-position: center center;
    background-size: contain;
    padding: 2px 5px;
    height: 88px;
    width: 100px;
    position: absolute;
    left: 0;
    right: 0;
    margin: 0 auto;
    text-align: center;
    display: block;
  }
  &__heading {
    text-align: center;
    h4 {
      font-family: $baton-medium;
      font-size: $font-x-large;
      text-transform: uppercase;
      color: $gunmetal;
    }
  }
  &__item {
    display: inline-block;
    padding: 2px 5px;
  }
  &__anchor {
    font-family: $baton-medium;
    text-transform: lowercase;
    text-decoration: none;
    font-size: $font-large;
    color: $springster-purple;
    &:hover {color: $black;}
    &:before {content: "#";}
  }
}
.article-page-tag-cloud {
  .heading {
    margin-bottom: 10px;
  }
}
