{% load wagtailcore_tags core_tags i18n %}
  {% if tag %}
  <div class="grid-teaser">
    <h1 class="grid-teaser__heading">
      <a href="{% pageurl tag %}" class="grid-teaser__heading-link">{{ tag }}</a>
    </h1>
    {% if articles %}
      <ul class="grid-teaser-list">
      {% for article in tag_articles %}
        <li class="grid-teaser-list__item">
          {% include "patterns/basics/article-teasers/sp_variations/teaser-thumbnail.html" with layouttype="grid" %}
          {% include "patterns/basics/article-teasers/sp_variations/teaser-title.html" with layouttype="grid" %}
        </li>
      {% endfor %}
      </ul>
      {% include "patterns/basics/buttons/sp_variations/text-tag-dir-arrow_button.html" with direction="right" %}
    {% endif %}
  </div>
  {% endif %}
