
.section-listing__title-theme-headings {
  border-top-style: dotted;
  border-top-width: 1px;
}
.section-listing__title-theme-headings,
.promoted-article__title--theme-headings  {
  padding: 5px 15px;
}

.section-listing__title-theme-general,
.section-listing__title-theme-standard {
  padding: 0 10px;
}

.section-listing__link-theme-headings,
.section-listing__title-theme-headings,
.section-listing__link-theme-standard {
  color: #000;
}


//Temporal Section Heading Style
.page__heading {
  color: #fff;
  position: absolute;
  top: 55px;
  left: 15px;
}
