@mixin no-list {
    margin: 0;
    padding: 0;
    list-style: none;
}


@mixin heading-fontsize-scale($headingFontSizeMap) {
  @each $screen-breakpoint, $font-size in $headingFontSizeMap {
    @if $screen-breakpoint == null {
      font-size: $font-size;
    }
    @else {
      @media screen and (min-width: $screen-breakpoint) {
        font-size: $font-size;
      }
    }
  }
}

@mixin float-clear($value) {
  float: $value;
  clear: $value;
}

@mixin divider-top-1 {
  background: url('/static/img/top-div-1@2x.png') no-repeat 0 0/contain;
  margin-top: 5px;
}
@mixin divider-top-2 {
  background: url('/static/img/top-div-2@2x.png') no-repeat 0 0/contain;
  margin-top: 5px;
}
@mixin divider-bottom-1 {
  background: url('/static/img/bottom-div-1@2x.png') no-repeat 0 100%/contain;
}
@mixin divider-combo-1 {
  background: url('/static/img/bottom-div-1@2x.png') no-repeat 0 100%/contain, url('/static/img/top-div-2@2x.png') no-repeat 0 0/contain;
  margin-top: 5px;
}

@mixin divider-combo-2 {
  background: url('/static/img/bottom-div-1@2x.png') no-repeat 0 100%/contain, url('/static/img/top-div-1@2x.png') no-repeat 0 0/contain;
  margin-top: 5px;
}

@mixin zig-zag-underline {
	background: url('/static/img/zig-zag-underline.png') no-repeat 50% 100%/145px;
  padding-bottom: 10px
}
