.section-article__heading {
  background: #f3f4f1;
  padding: 10px 15px;
}

.heading--section-article,
.section-article__icon-image {
  vertical-align: middle;
}
.section-article__icon-image {
  padding: 0 10px 0 0;
}
.heading--section-article,
.heading-section-article__link {
  display: inline-block;
  color: #000;
}
